pyxnat.CacheManager
===================

.. currentmodule:: pyxnat

.. autoclass:: CacheManager

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CacheManager.__init__
      ~CacheManager.available_disk
      ~CacheManager.clear
      ~CacheManager.disk_ready
      ~CacheManager.enable_warnings
      ~CacheManager.set_usage
      ~CacheManager.size
      ~CacheManager.total_disk
      ~CacheManager.used_disk
   
   

   
   
   